NaClient

Struct NaClient 

pub struct NaClient {
    pub address: String,
    pub api_key: String,
    pub http_client: Client,
}

Fields

address: Stringapi_key: Stringhttp_client: Client

Implementations

Source

impl NaClient

pub async fn new(api_key: String, address: String) -> Self

build the client to use local resolver, IE Ipv4

pub async fn get_data(&self, path: &str) -> Result<Value, NaApiError>

Call the get and parse the results We want to get the “data” attribute from the response for the calling endpoint. Exit with error message if “data” is not present This is shitty but it is safe enough so far as I can tell at this point